@@ -1,5 +1,8 @@
-use crate::testing::constants::{DB, GENESIS_EPOCH_POST_END, GENESIS_EPOCH_START};
-use crate::testing::utils::random_valid_txx;
+use crate::{
+    testing::constants::{DB, GENESIS_EPOCH_POST_END, GENESIS_EPOCH_START},
+    State,
+};
+use crate::{testing::utils::random_valid_txx, GenesisConfig};
 
 // const GENESIS_MEL_SUPPLY: u128 = 21_000_000;
 // const GENESIS_NUM_STAKERS: u64 = 10;
@@ -8,15 +11,15 @@ use crate::testing::utils::random_valid_txx;
 // const GENESIS_STAKER_WEIGHT: u128 = 100;
 // pub const SEND_MEL_AMOUNT: u128 = 30_000_000_000;
 
-use crate::melvm::{Address, Covenant};
-use crate::{
-    CoinData, CoinDataHeight, CoinID, CoinValue, Denom, GenesisConfig, StakeDoc, State,
-    Transaction, MICRO_CONVERTER,
-};
+use crate::melvm::Covenant;
 
 use std::collections::HashMap;
 
 use novasmt::{Database, InMemoryCas};
+use themelio_structs::{
+    Address, CoinData, CoinDataHeight, CoinID, CoinValue, Denom, StakeDoc, Transaction,
+    MICRO_CONVERTER,
+};
 use tmelcrypt::{Ed25519PK, Ed25519SK};
 
 pub fn valid_txx(keypair: (Ed25519PK, Ed25519SK)) -> Vec<Transaction> {
@@ -54,7 +57,7 @@ pub fn create_state(
     // Insert a mel coin into state so we can transact
     let start_micromels: CoinValue = CoinValue(10000);
     let start_conshash: Address = Covenant::always_true().hash();
-    state.coins.insert(
+    state.coins.insert_coin(
         CoinID {
             txhash: tmelcrypt::HashVal([0; 32]).into(),
             index: 0,
@@ -68,6 +71,7 @@ pub fn create_state(
             },
             height: 0.into(),
         },
+        state.tip_906(),
     );
 
     // Insert data need for staking proofs
@@ -103,9 +107,11 @@ pub fn genesis_state(
     let mut state = GenesisConfig::std_testnet().realize(&DB);
 
     // insert initial mel coin supply
-    state
-        .coins
-        .insert(genesis_mel_coin_id, genesis_mel_coin_data_height);
+    state.coins.insert_coin(
+        genesis_mel_coin_id,
+        genesis_mel_coin_data_height,
+        state.tip_906(),
+    );
 
     // Insert stake holders
     for (i, (&keypair, &syms_staked)) in genesis_stakeholders.iter().enumerate() {
